==> huaweicloudsdkvpc-3.1.123-py2.py3-none-any.whl: huaweicloudsdkvpc/v2/model/delete_security_group_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSecurityGroupTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'key': 'str',
        'security_group_id': 'str'
    }

    attribute_map = {
        'key': 'key',
        'security_group_id': 'security_group_id'
    }

    def __init__(self, key=None, security_group_id=None):
        """DeleteSecurityGroupTagRequest

        The model defined in huaweicloud sdk

        :param key: 功能说明：键值
        :type key: str
        :param security_group_id: 安全组资源ID
        :type security_group_id: str
        """
        
        

        self._key = None
        self._security_group_id = None
        self.discriminator = None

        self.key = key
        self.security_group_id = security_group_id

    @property
    def key(self):
        """Gets the key of this DeleteSecurityGroupTagRequest.

        功能说明：键值

        :return: The key of this DeleteSecurityGroupTagRequest.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this DeleteSecurityGroupTagRequest.

        功能说明：键值

        :param key: The key of this DeleteSecurityGroupTagRequest.
        :type key: str
        """
        self._key = key

    @property
    def security_group_id(self):
        """Gets the security_group_id of this DeleteSecurityGroupTagRequest.

        安全组资源ID

        :return: The security_group_id of this DeleteSecurityGroupTagRequest.
        :rtype: str
        """
        return self._security_group_id

    @security_group_id.setter
    def security_group_id(self, security_group_id):
        """Sets the security_group_id of this DeleteSecurityGroupTagRequest.

        安全组资源ID

        :param security_group_id: The security_group_id of this DeleteSecurityGroupTagRequest.
        :type security_group_id: str
        """
        self._security_group_id = security_group_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSecurityGroupTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v2/model/delete_security_group_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteSecurityGroupTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'key': 'str',
        'security_group_id': 'str'
    }

    attribute_map = {
        'key': 'key',
        'security_group_id': 'security_group_id'
    }

    def __init__(self, key=None, security_group_id=None):
        r"""DeleteSecurityGroupTagRequest

        The model defined in huaweicloud sdk

        :param key: 功能说明：键值
        :type key: str
        :param security_group_id: 安全组资源ID
        :type security_group_id: str
        """
        
        

        self._key = None
        self._security_group_id = None
        self.discriminator = None

        self.key = key
        self.security_group_id = security_group_id

    @property
    def key(self):
        r"""Gets the key of this DeleteSecurityGroupTagRequest.

        功能说明：键值

        :return: The key of this DeleteSecurityGroupTagRequest.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        r"""Sets the key of this DeleteSecurityGroupTagRequest.

        功能说明：键值

        :param key: The key of this DeleteSecurityGroupTagRequest.
        :type key: str
        """
        self._key = key

    @property
    def security_group_id(self):
        r"""Gets the security_group_id of this DeleteSecurityGroupTagRequest.

        安全组资源ID

        :return: The security_group_id of this DeleteSecurityGroupTagRequest.
        :rtype: str
        """
        return self._security_group_id

    @security_group_id.setter
    def security_group_id(self, security_group_id):
        r"""Sets the security_group_id of this DeleteSecurityGroupTagRequest.

        安全组资源ID

        :param security_group_id: The security_group_id of this DeleteSecurityGroupTagRequest.
        :type security_group_id: str
        """
        self._security_group_id = security_group_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteSecurityGroupTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
